// Vertex Shader  file "water.vert"	

#version 330

uniform mat4 modelViewMatrix;	//model-view matrix
uniform mat4 projectionMatrix;	//projection matrix
uniform vec3 eyePositionWorld;	//eye position in world coordinates
uniform mat4 modelToWorld;		//model to world transformation matrix

in vec4 vertex;		//local coordinates
in vec3 normal;		//local normals

uniform float time;	//ellapsed time (framerate dependent, continous)

out vec4 viewPos;	//view position
out vec3 R;			//reflection

void main() {
	vec4 v = vertex;
	v.y += 0.2 * sin(0.75 * v.x + time * 3.0) + 0.2 * sin(0.77 * v.z + time * 2.7);
 
	viewPos = modelViewMatrix * v;

	vec3 positionWorld = (modelToWorld * v).xyz;
	vec3 N = normalize(mat3(modelToWorld) * normal);

	vec3 V = positionWorld - eyePositionWorld;
	R = reflect(V, N);
	
	gl_Position = projectionMatrix * viewPos;
}